ShopLiveCommonAuth class

Constructors

ShopLiveCommonAuth({String? userJWT, String? guestUid, String? accessKey, String? utmSource, String? utmMedium, String? utmCampaign, String? utmContent})

Properties

accessKey ↔ String?
getter/setter pair
guestUid ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userJWT ↔ String?
getter/setter pair
utmCampaign ↔ String?
getter/setter pair
utmContent ↔ String?
getter/setter pair
utmMedium ↔ String?
getter/setter pair
utmSource ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited