ShopLiveCommonUser class

Constructors

ShopLiveCommonUser({required String userId, String? userName, int? age, ShopLiveCommonUserGender? gender, int? userScore, Map<String, dynamic>? custom})

Properties

age ↔ int?
getter/setter pair
custom ↔ Map<String, dynamic>?
getter/setter pair
gender ↔ ShopLiveCommonUserGender?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
final
userName ↔ String?
getter/setter pair
userScore ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited