MethodChannelShopliveCommon class

An implementation of ShoplivePlayerPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAuth() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAccessKey({required String? accessKey}) → void
override
setAuth({required ShopLiveCommonAuth data}) → void
override
setAuthToken({required String? userJWT}) → void
override
setUser({required String accessKey, required ShopLiveCommonUser user}) → void
override
setUtmCampaign({required String? utmCampaign}) → void
override
setUtmContent({required String? utmContent}) → void
override
setUtmMedium({required String? utmMedium}) → void
override
setUtmSource({required String? utmSource}) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited