MethodChannelShoplivePlayer class

An implementation of ShoplivePlayerPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addParameter({required String key, required String? value}) → void
override
close() → void
override
getPluginVersion() → Future<String>
override
getSdkVersion() → Future<String>
override
hidePreview() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
play({required ShopLivePlayerData data}) → void
override
removeParameter({required String key}) → void
override
sendCommandMessage({required String command, required Map<String, dynamic> payload}) → void
override
sendCustomActionResult({required String id, required bool success, required String message, required String popupStatus, required String alertType}) → Future<void>
override
sendDownloadCouponResult({required String couponId, required bool success, required String message, required String popupStatus, required String alertType}) → Future<void>
override
setEndpoint({required String? endpoint}) → void
override
setEnterPipModeOnBackPressed({required bool isEnterPipMode}) → void
override
setMixWithOthers({required bool isMixAudio}) → void
override
setMuteWhenPlayStart({required bool isMute}) → void
override
setNextActionOnHandleNavigation({required ShopLiveActionType type}) → void
override
setPreviewOption({required ShopLivePlayerPreviewData data}) → void
override
setResizeMode({required ShopLiveResizeMode mode}) → void
override
setShareScheme({required String shareSchemeUrl}) → void
override
showPreview({required String campaignKey}) → void
override
startPictureInPicture() → void
override
stopPictureInPicture() → void
override
toString() → String
A string representation of this object.
inherited
useCloseButton({required bool canUse}) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited