ShopLiveShortformCollectionData class

Constructors

ShopLiveShortformCollectionData({String? shortsId, String? shortsCollectionId, List<String>? tags, ShopLiveShortformTagSearchOperator? tagSearchOperator, List<String>? brands, List<String>? skus, bool shuffle = false, String? referrer})
ShopLiveShortformCollectionData.fromJson(Map<String, dynamic> json)
factory

Properties

brands ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
referrer ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortsCollectionId ↔ String?
getter/setter pair
shortsId ↔ String?
getter/setter pair
shuffle ↔ bool
getter/setter pair
skus ↔ List<String>?
getter/setter pair
tags ↔ List<String>?
getter/setter pair
tagSearchOperator ↔ ShopLiveShortformTagSearchOperator?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited